summaryrefslogtreecommitdiff
path: root/lib/repeatform.php
diff options
context:
space:
mode:
authorEvan Prodromou <evan@status.net>2009-12-11 10:49:26 -0500
committerEvan Prodromou <evan@status.net>2009-12-11 10:49:26 -0500
commit81843f2acd5375a9072d091fd58c6a6af079295e (patch)
tree00de15d57a7e361408a561b4762f491011d42235 /lib/repeatform.php
parentc9649f932153e6636214841858fd265b1476c05b (diff)
show the repeat form in notice lists
Diffstat (limited to 'lib/repeatform.php')
-rw-r--r--lib/repeatform.php26
1 files changed, 12 insertions, 14 deletions
diff --git a/lib/repeatform.php b/lib/repeatform.php
index 2052856ae..50e5d6dbe 100644
--- a/lib/repeatform.php
+++ b/lib/repeatform.php
@@ -2,7 +2,7 @@
/**
* StatusNet, the distributed open-source microblogging tool
*
- * Form for forwarding a notice
+ * Form for repeating a notice
*
* PHP version 5
*
@@ -27,14 +27,12 @@
* @link http://status.net/
*/
-if (!defined('STATUSNET') && !defined('LACONICA')) {
+if (!defined('STATUSNET')) {
exit(1);
}
-require_once INSTALLDIR.'/lib/form.php';
-
/**
- * Form for forwarding a notice
+ * Form for repeating a notice
*
* @category Form
* @package StatusNet
@@ -43,10 +41,10 @@ require_once INSTALLDIR.'/lib/form.php';
* @link http://status.net/
*/
-class ForwardForm extends Form
+class RepeatForm extends Form
{
/**
* Notice to forward
*/
var $notice = null;
@@ -55,7 +53,7 @@ class ForwardForm extends Form
* Constructor
*
* @param HTMLOutputter $out output channel
* @param Notice $notice notice to forward
*/
function __construct($out=null, $notice=null)
@@ -73,7 +71,7 @@ class ForwardForm extends Form
function id()
{
- return 'forward-' . $this->notice->id;
+ return 'repeat-' . $this->notice->id;
}
/**
@@ -84,7 +82,7 @@ class ForwardForm extends Form
function action()
{
- return common_local_url('forward');
+ return common_local_url('repeat');
}
/**
@@ -106,7 +104,7 @@ class ForwardForm extends Form
*/
function formLegend()
{
- $this->out->element('legend', null, _('Forward this notice'));
+ $this->out->element('legend', null, _('Repeat this notice'));
}
/**
@@ -130,8 +128,8 @@ class ForwardForm extends Form
function formActions()
{
- $this->out->submit('forward-submit-' . $this->notice->id,
- _('Forward'), 'submit', null, _('Forward this notice'));
+ $this->out->submit('repeat-submit-' . $this->notice->id,
+ _('Repeat'), 'submit', null, _('Repeat this notice'));
}
/**
@@ -142,6 +140,6 @@ class ForwardForm extends Form
function formClass()
{
- return 'form_forward';
+ return 'form_repeat';
}
}
@@ -43,10 +41,10 @@ require_once INSTALLDIR.'/lib/form.php';
{
/**
- * Notice to forward
+ * Notice to repeat
*/
var $notice = null;
@@ -55,7 +53,7 @@ class ForwardForm extends Form
*
* @param HTMLOutputter $out output channel
- * @param Notice $notice notice to forward
+ * @param Notice $notice notice to repeat
*/
function __construct($out=null, $notice=null)